@@ -13,7 +13,8 @@
 #include <qspinbox.h>
 #include <qpushbutton.h>
 #include <qcombobox.h>
-#include <debug.h>
+
+#include "debug.h"
 
 #include "pop3.h"
 
@@ -25,12 +26,12 @@ class AccountDialog: public QDialog
 		AccountDialog(Pop3Proto* acc);
 
 	private:
-		QGrid* layout;
+		QGrid *layout;
 		QLineEdit *name, *host, *user, *password;
 		QSpinBox *port;
 		QPushButton *ok, *cancel;
 		QComboBox *conntype;
-		Pop3Proto* acc;
+		Pop3Proto *Acc;
 
 	private slots:
 		void save();		
