@@ -10,13 +10,16 @@
 #include "debug.h"
 #include "modules.h"
 #include "../sms/sms.h"
-#include "smsmiastoplusagatewayslots.h"
+#include "ui_handler.h"
+#include "smsmiastoplusagateway.h"
+
+miastoplusa_sms::UIHandler uiHandler;
 
 extern "C" int miastoplusa_sms_init()
 {
 	kdebugf();
-	smsslots->registerGateway("miastoplusa", &SmsMiastoplusaGatewaySlots::isValidMiastoplusa);
-	sms_miastoplusa_gateway_slots=new SmsMiastoplusaGatewaySlots(NULL, "sms_miastoplusa_gateway_slots");
+	smsConfigurationUiHandler->registerGateway("miastoplusa", &SmsMiastoplusaGateway::isValidMiastoplusa);
+	MainConfigurationWindow::registerUiFile(dataPath("kadu/modules/configuration/miastoplusa_sms.ui"), &uiHandler);
 	kdebugf2();
 	return 0;
 }
@@ -24,8 +27,8 @@ extern "C" int miastoplusa_sms_init()
 extern "C" void miastoplusa_sms_close()
 {
 	kdebugf();
-	smsslots->unregisterGateway("miastoplusa");
-	delete sms_miastoplusa_gateway_slots;
+	MainConfigurationWindow::unregisterUiFile(dataPath("kadu/modules/configuration/miastoplusa_sms.ui"), &uiHandler);
+	smsConfigurationUiHandler->unregisterGateway("miastoplusa");
 	kdebugf2();
 }
 
