@@ -10,14 +10,18 @@ class QResizeEvent;
 /** @ingroup account_management
  * @{
  */
-class ChangePassword : public QHBox {
+class ChangePassword : public QHBox 
+{
 	Q_OBJECT
+
 	public:
-		ChangePassword(QDialog *parent = 0, const char *name = 0);
+		ChangePassword(QDialog *parent = 0, const char *name = "change_password");
 		~ChangePassword();
 
 	private:
-		QLineEdit *emailedit, *newpwd, *newpwd2;
+		QLineEdit *emailedit;
+		QLineEdit *newpwd;
+		QLineEdit *newpwd2;
 		LayoutHelper *layoutHelper;
 
 	private slots:
@@ -28,5 +32,7 @@ class ChangePassword : public QHBox {
 	protected:
 		virtual void resizeEvent(QResizeEvent *);
 };
+
 /** @} */
+
 #endif
