@@ -13,15 +13,17 @@ class QResizeEvent;
 /** @ingroup account_management
  * @{
  */
-class Unregister : public QHBox {
+class Unregister : public QHBox 
+{
 	Q_OBJECT
 
 	public:
-		Unregister(QDialog* parent = 0, const char *name = 0);
+		Unregister(QDialog* parent = 0, const char *name = "unregister_user");
 		~Unregister();
 
 	private:
-		QLineEdit *uin, *pwd;
+		QLineEdit *uin;
+		QLineEdit *pwd;
 		QLabel *status;
 		QCheckBox *updateconfig;
 		LayoutHelper *layoutHelper;
@@ -38,6 +40,7 @@ class Unregister : public QHBox {
 	protected:
 		virtual void resizeEvent(QResizeEvent *);
 };
-/** @} */
-#endif
 
+/** @} */
+
+#endif
