@@ -13,12 +13,13 @@
 #include <qstring.h>
 
 #include "action.h"
-#include "config_dialog.h"
 #include "config_file.h"
 #include "debug.h"
-#include "history.h"
+#include "../history/history.h"
+#include "hot_key.h"
 #include "icons_manager.h"
 #include "kadu.h"
+#include "message_box.h"
 #include "modules.h"
 #include "sms.h"
 #include "userbox.h"
@@ -30,51 +31,17 @@
 extern "C" int sms_init()
 {
 	kdebugf();
-	ConfigDialog::addTab(QT_TRANSLATE_NOOP("@default", "SMS"), "SMSTab");
 
-	ConfigDialog::addVBox("SMS", "SMS", "sms-beginner");
-
-	ConfigDialog::addHGroupBox("SMS", "SMS",
-			QT_TRANSLATE_NOOP("@default", "Gateways priority"), 0, Advanced);
-	ConfigDialog::addListBox("SMS", "Gateways priority", "gateways");
-	ConfigDialog::addVBox("SMS", "Gateways priority", "button");
-	ConfigDialog::addPushButton("SMS", "button", QT_TRANSLATE_NOOP("@default", "Up"));
-	ConfigDialog::addPushButton("SMS", "button", QT_TRANSLATE_NOOP("@default", "Down"));
-	ConfigDialog::addHotKeyEdit("ShortCuts", "Define keys",
-			QT_TRANSLATE_NOOP("@default", "Send SMS"), "kadu_sendsms", "Ctrl+S");
-
-	ConfigDialog::addVGroupBox("SMS", "SMS",
-			QT_TRANSLATE_NOOP("@default", "SMS options"), 0, Expert);
-	ConfigDialog::addCheckBox("SMS", "SMS options",
-			QT_TRANSLATE_NOOP("@default", "Use built-in SMS application"), "BuiltInApp", true);
-	ConfigDialog::addLineEdit("SMS", "SMS options",
-			QT_TRANSLATE_NOOP("@default", "Custom SMS application"), "SmsApp");
-	ConfigDialog::addGrid("SMS", "SMS options", "smsgrid", 2);
-	ConfigDialog::addCheckBox("SMS", "smsgrid",
-			QT_TRANSLATE_NOOP("@default", "SMS custom string"), "UseCustomString", false ,
-			QT_TRANSLATE_NOOP("@default", "Check this box if your sms application doesn't understand arguments: number \"message\"\nArguments should be separated with spaces. %n argument is converted to number, %m to message"));
-	ConfigDialog::addLineEdit("SMS", "smsgrid", 0, "SmsString", QString::null, 0, "smsstring");
-	ConfigDialog::addLineEdit("SMS", "SMS options",
-			QT_TRANSLATE_NOOP("@default", "SMS Nick"), "SmsNick");
-	config_file.addVariable("SMS", "SmsNick", config_file.readEntry("General", "Nick"));
-
-
-	smsslots=new SmsSlots(NULL, "smsslots");
-	ConfigDialog::registerSlotOnCreateTab("SMS", smsslots, SLOT(onCreateTabSMS()));
-	ConfigDialog::registerSlotOnCloseTab("SMS", smsslots, SLOT(onCloseTabSMS()));
-	ConfigDialog::registerSlotOnApplyTab("SMS", smsslots, SLOT(onApplyTabSMS()));
-
-	ConfigDialog::connectSlot("SMS", "Use built-in SMS application", SIGNAL(toggled(bool)), smsslots, SLOT(onSmsBuildInCheckToggle(bool)));
-	ConfigDialog::connectSlot("SMS", "Up", SIGNAL(clicked()), smsslots, SLOT(onUpButton()));
-	ConfigDialog::connectSlot("SMS", "Down", SIGNAL(clicked()), smsslots, SLOT(onDownButton()));
+	smsConfigurationUiHandler = new SmsConfigurationUiHandler();
+	MainConfigurationWindow::registerUiFile(dataPath("kadu/modules/configuration/sms.ui"), smsConfigurationUiHandler);
 
 	QObject::connect(kadu->userbox(), SIGNAL(doubleClicked(UserListElement)),
-			smsslots, SLOT(onUserDblClicked(UserListElement)));
+			smsConfigurationUiHandler, SLOT(onUserDblClicked(UserListElement)));
 	QObject::connect(kadu->userbox(), SIGNAL(mouseButtonClicked(int, QListBoxItem*,const QPoint&)),
-			smsslots, SLOT(onUserClicked(int, QListBoxItem*, const QPoint&)));
+			smsConfigurationUiHandler, SLOT(onUserClicked(int, QListBoxItem*, const QPoint&)));
 	QObject::connect(kadu->userbox(), SIGNAL(returnPressed(UserListElement)),
-			smsslots, SLOT(onUserDblClicked(UserListElement)));
-	QObject::connect(UserBox::userboxmenu, SIGNAL(popup()), smsslots, SLOT(onPopupMenuCreate()));
+			smsConfigurationUiHandler, SLOT(onUserDblClicked(UserListElement)));
+	QObject::connect(UserBox::userboxmenu, SIGNAL(popup()), smsConfigurationUiHandler, SLOT(onPopupMenuCreate()));
 
 	config_file.addVariable("SMS", "Priority", QString::null);
 	kdebugf2();
@@ -85,47 +52,25 @@ extern "C" void sms_close()
 {
 	kdebugf();
 
-	ConfigDialog::unregisterSlotOnCreateTab("SMS", smsslots, SLOT(onCreateTabSMS()));
-	ConfigDialog::unregisterSlotOnCloseTab("SMS", smsslots, SLOT(onCloseTabSMS()));
-	ConfigDialog::unregisterSlotOnApplyTab("SMS", smsslots, SLOT(onApplyTabSMS()));
-
-	ConfigDialog::disconnectSlot("SMS", "Use built-in SMS application", SIGNAL(toggled(bool)), smsslots, SLOT(onSmsBuildInCheckToggle(bool)));
-	ConfigDialog::disconnectSlot("SMS", "Up", SIGNAL(clicked()), smsslots, SLOT(onUpButton()));
-	ConfigDialog::disconnectSlot("SMS", "Down", SIGNAL(clicked()), smsslots, SLOT(onDownButton()));
-
-	ConfigDialog::removeControl("ShortCuts", "Send SMS");
-	ConfigDialog::removeControl("SMS", "Up");
-	ConfigDialog::removeControl("SMS", "Down");
-	ConfigDialog::removeControl("SMS", "button");
-	ConfigDialog::removeControl("SMS", "gateways");
-	ConfigDialog::removeControl("SMS", "Gateways priority");
-	ConfigDialog::removeControl("SMS", "SMS Nick");
-	ConfigDialog::removeControl("SMS", 0, "smsstring");
-	ConfigDialog::removeControl("SMS", "SMS custom string");
-	ConfigDialog::removeControl("SMS", "smsgrid");
-	ConfigDialog::removeControl("SMS", "Custom SMS application");
-	ConfigDialog::removeControl("SMS", "Use built-in SMS application");
-	ConfigDialog::removeControl("SMS", "SMS options");
-	ConfigDialog::removeControl("SMS", "sms-beginner");
-	ConfigDialog::removeTab("SMS");
-
 	QObject::disconnect(kadu->userbox(), SIGNAL(doubleClicked(UserListElement)),
-			smsslots, SLOT(onUserDblClicked(UserListElement)));
+			smsConfigurationUiHandler, SLOT(onUserDblClicked(UserListElement)));
 	QObject::disconnect(kadu->userbox(), SIGNAL(returnPressed(UserListElement)),
-			smsslots, SLOT(onUserDblClicked(UserListElement)));
+			smsConfigurationUiHandler, SLOT(onUserDblClicked(UserListElement)));
 	QObject::disconnect(kadu->userbox(), SIGNAL(mouseButtonClicked(int, QListBoxItem*,const QPoint&)),
-			smsslots, SLOT(onUserClicked(int, QListBoxItem*, const QPoint&)));
-	QObject::disconnect(UserBox::userboxmenu, SIGNAL(popup()), smsslots, SLOT(onPopupMenuCreate()));
+			smsConfigurationUiHandler, SLOT(onUserClicked(int, QListBoxItem*, const QPoint&)));
+	QObject::disconnect(UserBox::userboxmenu, SIGNAL(popup()), smsConfigurationUiHandler, SLOT(onPopupMenuCreate()));
+
+	MainConfigurationWindow::unregisterUiFile(dataPath("kadu/modules/configuration/sms.ui"), smsConfigurationUiHandler);
+	delete smsConfigurationUiHandler;
+	smsConfigurationUiHandler = 0;
 
-	delete smsslots;
-	smsslots=NULL;
 	kdebugf2();
 }
 
 /********** SmsImageDialog **********/
 
-SmsImageDialog::SmsImageDialog(QDialog* parent, const QByteArray& image)
-	: QDialog (parent, "SmsImageDialog"), code_edit(0)
+SmsImageDialog::SmsImageDialog(QWidget* parent, const QByteArray& image)
+	: QDialog(parent, "SmsImageDialog"), code_edit(0)
 {
 	kdebugf();
 
@@ -178,7 +123,7 @@ SmsGateway::SmsGateway(QObject* parent, const char *name)
 void SmsGateway::httpError()
 {
 	kdebugf();
-	QMessageBox::critical((QDialog*)(parent()->parent()), "SMS", tr("Network error. Provider gateway page is probably unavailable"));
+	MessageBox::msg(tr("Network error. Provider gateway page is probably unavailable"), false, "Warning", (QDialog*)(parent()->parent()));
 	emit finished(false);
 	kdebugf2();
 }
@@ -215,23 +160,23 @@ void SmsSender::send(const QString& number,const QString& message, const QString
 		Number=Number.right(9);
 	if (Number.length()!=9)
 	{
-		QMessageBox::critical((QWidget*)parent(), "SMS", tr("Mobile number is incorrect"));
+		MessageBox::msg(tr("Mobile number is incorrect"), false, "Warning", (QWidget*)parent());
 		emit finished(false);
 		kdebugf2();
 		return;
 	}
 	if (signature.isEmpty())
 	{
-		QMessageBox::critical((QWidget*)parent(), "SMS", tr("Signature can't be empty"));
+		MessageBox::msg(tr("Signature can't be empty"), false, "Warning", (QWidget*)parent());
 		emit finished(false);
 		kdebugf2();
 		return;
 	}
-	Gateway=smsslots->getGateway(Number);
+	Gateway=smsConfigurationUiHandler->getGateway(Number);
 
 	if (Gateway==NULL)
 	{
-		QMessageBox::critical((QWidget*)parent(),"SMS", tr("Mobile number is incorrect or gateway is not available"));
+		MessageBox::msg(tr("Mobile number is incorrect or gateway is not available"), false, "Warning", (QWidget*)parent());
 		emit finished(false);
 		kdebugf2();
 		return;
@@ -244,36 +189,38 @@ void SmsSender::send(const QString& number,const QString& message, const QString
 
 /********** Sms **********/
 
-Sms::Sms(const QString& altnick, QDialog* parent, const char *name) : QDialog (parent, name),
+Sms::Sms(const QString& altnick, QWidget* parent, const char *name) : QWidget(parent, name, WType_TopLevel | WDestructiveClose),
 	body(0), recipient(0), list(0), smslen(0), l_contact(0), e_contact(0), l_signature(0),
 	e_signature(0), b_send(0), c_saveInHistory(0), smsProcess(0), Sender()
 {
 	kdebugf();
-	QGridLayout * grid = new QGridLayout(this, 3, 4, 10, 7);
 
-	setWFlags(WDestructiveClose);
+	QGridLayout *grid = new QGridLayout(this, 3, 4, 10, 7);
 
 	body = new QMultiLineEdit(this);
 	grid->addMultiCellWidget(body, 1, 1, 0, 3);
 	body->setWordWrap(QMultiLineEdit::WidgetWidth);
-	body->setFont(config_file.readFontEntry("Look","ChatFont"));
 	body->setTabChangesFocus(true);
-	QObject::connect(body, SIGNAL(textChanged()), this, SLOT(updateCounter()));
+	connect(body, SIGNAL(textChanged()), this, SLOT(updateCounter()));
 
 	recipient = new QLineEdit(this);
 	recipient->setMinimumWidth(140);
-	if (!altnick.isEmpty())
+	if (altnick.isEmpty())
+		recipient->setFocus();
+	else
 		recipient->setText(userlist->byAltNick(altnick).mobile());
-	QObject::connect(recipient, SIGNAL(textChanged(const QString&)), this, SLOT(updateList(const QString&)));
+	connect(recipient, SIGNAL(textChanged(const QString&)), this, SLOT(updateList(const QString&)));
+	connect(recipient, SIGNAL(returnPressed()), this, SLOT(editReturnPressed()));
 	grid->addWidget(recipient, 0, 1);
 
-	QStringList strlist;
-	list = new QComboBox(this);
+	QStringList strlist; // lista kontaktow z przypisanym numerem telefonu
 	CONST_FOREACH(user, *userlist)
 		if (!(*user).mobile().isEmpty())
 		 	strlist.append((*user).altNick());
 	strlist.sort();
-	strlist.insert(strlist.begin(), QString::null);
+	strlist.prepend(QString::null);
+
+	list = new QComboBox(this);
 	list->insertStringList(strlist);
 	list->setCurrentText(altnick);
 	connect(list, SIGNAL(activated(const QString&)), this, SLOT(updateRecipient(const QString &)));
@@ -282,17 +229,19 @@ Sms::Sms(const QString& altnick, QDialog* parent, const char *name) : QDialog (p
 	QLabel *recilabel = new QLabel(tr("Recipient"), this);
 	grid->addWidget(recilabel, 0, 0);
 
-	l_contact= new QLabel(tr("Contact"), this);
+	l_contact = new QLabel(tr("Contact"), this);
 	grid->addWidget(l_contact, 3, 0);
-	e_contact= new QLineEdit(this);
+	e_contact = new QLineEdit(this);
+	connect(e_contact, SIGNAL(returnPressed()), this, SLOT(editReturnPressed()));
 	grid->addWidget(e_contact, 3, 1);
 
 	smslen = new QLabel("0", this);
 	grid->addWidget(smslen, 3, 3, Qt::AlignRight);
 
-	l_signature= new QLabel(tr("Signature"), this);
+	l_signature = new QLabel(tr("Signature"), this);
 	grid->addWidget(l_signature, 4, 0);
-	e_signature= new QLineEdit(config_file.readEntry("SMS", "SmsNick"), this);
+	e_signature = new QLineEdit(config_file.readEntry("SMS", "SmsNick"), this);
+	connect(e_signature, SIGNAL(returnPressed()), this, SLOT(editReturnPressed()));
 	grid->addWidget(e_signature, 4, 1);
 
 	c_saveInHistory = new QCheckBox(tr("Save SMS in history"), this);
@@ -300,28 +249,37 @@ Sms::Sms(const QString& altnick, QDialog* parent, const char *name) : QDialog (p
 	grid->addMultiCellWidget(c_saveInHistory, 5, 5, 0, 1);
 
 	b_send = new QPushButton(this);
-	b_send->setIconSet(icons_manager->loadIcon("SendSMSButton"));
-	b_send->setText(tr("Send"));
+	b_send->setIconSet(icons_manager->loadIconSet("SendSMSButton"));
+	b_send->setText(tr("&Send"));
+	b_send->setDefault(true);
 	b_send->setMaximumWidth(200);
+	connect(b_send, SIGNAL(clicked()), this, SLOT(editReturnPressed()));
 	grid->addWidget(b_send, 5, 3, Qt::AlignRight);
 
-	if (altnick.isEmpty())
-		recipient->setFocus();
 	resize(400, 250);
 	setCaption(tr("Send SMS"));
 
-	connect(b_send, SIGNAL(clicked()), this, SLOT(sendSms()));
 	connect(&Sender, SIGNAL(finished(bool)), this, SLOT(onSmsSenderFinished(bool)));
 
+	configurationUpdated();
+	loadGeometry(this, "Sms", "SmsDialogGeometry", 200, 200, 400, 250);
+
 	modules_manager->moduleIncUsageCount("sms");
 	kdebugf2();
 }
 
 Sms::~Sms()
 {
+	saveGeometry(this, "Sms", "SmsDialogGeometry");
+
 	modules_manager->moduleDecUsageCount("sms");
 }
 
+void Sms::configurationUpdated()
+{
+	body->setFont(config_file.readFontEntry("Look","ChatFont"));
+}
+
 void Sms::setRecipient(const QString &phone)
 {
     kdebugf();
@@ -364,6 +322,18 @@ void Sms::updateList(const QString &newnumber)
 	kdebugf2();
 }
 
+void Sms::editReturnPressed(void)
+{
+	kdebugf();
+
+	if (body->text().isEmpty())
+		body->setFocus();
+	else
+		sendSms();
+
+	kdebugf2();
+}
+
 void Sms::sendSms(void)
 {
 	kdebugf();
@@ -375,29 +345,29 @@ void Sms::sendSms(void)
 	l_signature->setEnabled(false);
 	c_saveInHistory->setEnabled(false);
 
-	if (config_file.readBoolEntry("SMS","BuiltInApp"))
+	if (config_file.readBoolEntry("SMS", "BuiltInApp"))
 	{
 		Sender.send(recipient->text(), body->text(), e_contact->text(), e_signature->text());
 	}
 	else
 	{
-		if (config_file.readEntry("SMS","SmsApp").isEmpty())
+		if (config_file.readEntry("SMS", "SmsApp").isEmpty())
 		{
-			QMessageBox::warning(this, tr("SMS error"), tr("Sms application was not specified. Visit the configuration section") );
+			MessageBox::msg(tr("Sms application was not specified. Visit the configuration section"), false, "Warning", this);
 			kdebugm(KDEBUG_WARNING, "SMS application NOT specified. Exit.\n");
 			return;
 		}
-		QString SmsAppPath=config_file.readEntry("SMS","SmsApp");
+		QString SmsAppPath = config_file.readEntry("SMS", "SmsApp");
 
 		smsProcess = new QProcess(this);
-		if (config_file.readBoolEntry("SMS","UseCustomString")&&
-			(!config_file.readBoolEntry("SMS","BuiltInApp")))
+		if (config_file.readBoolEntry("SMS", "UseCustomString")&&
+			(!config_file.readBoolEntry("SMS", "BuiltInApp")))
 		{
-			QStringList args=QStringList::split(' ',config_file.readEntry("SMS","SmsString"));
-			if(args.find("%n")!=args.end())
-				*args.find("%n")=recipient->text();
-			if(args.find("%m")!=args.end())
-				*args.find("%m")=body->text();
+			QStringList args = QStringList::split(' ', config_file.readEntry("SMS", "SmsString"));
+			if(args.find("%n") != args.end())
+				*args.find("%n") = recipient->text();
+			if(args.find("%m") != args.end())
+				*args.find("%m") = body->text();
 			args.prepend(SmsAppPath);
 			smsProcess->setArguments(args);
 		}
@@ -409,7 +379,7 @@ void Sms::sendSms(void)
 		}
 
 		if (!smsProcess->start())
-			QMessageBox::critical(this, tr("SMS error"), tr("Could not spawn child process. Check if the program is functional") );
+			MessageBox::msg(tr("Could not spawn child process. Check if the program is functional"), false, "Warning", this);
 		QObject::connect(smsProcess, SIGNAL(processExited()), this, SLOT(smsSigHandler()));
 	}
 	kdebugf2();
@@ -419,9 +389,9 @@ void Sms::smsSigHandler()
 {
 	kdebugf();
 	if (smsProcess->normalExit())
-		QMessageBox::information(this, tr("SMS sent"), tr("The process exited normally. The SMS should be on its way"));
+		MessageBox::msg(tr("The process exited normally. The SMS should be on its way"), false, "Information", this);
 	else
-		QMessageBox::warning(this, tr("SMS not sent"), tr("The process exited abnormally. The SMS may not be sent"));
+		MessageBox::msg(tr("The process exited abnormally. The SMS may not be sent"), false, "Warning", this);
 	delete smsProcess;
 	smsProcess = NULL;
 
@@ -448,7 +418,8 @@ void Sms::onSmsSenderFinished(bool success)
 	{
 		if (c_saveInHistory->isChecked())
 			history->appendSms(recipient->text(), body->text());
-		QMessageBox::information(this, tr("SMS sent"), tr("The SMS was sent and should be on its way"));
+		if (!MessageBox::ask(tr("The SMS was sent and should be on its way.\nDo you want to send next message?"), "Information", this))
+			deleteLater();
 		body->clear();
 	}
 	b_send->setEnabled(true);
@@ -461,130 +432,102 @@ void Sms::onSmsSenderFinished(bool success)
 	kdebugf2();
 }
 
-SmsSlots::SmsSlots(QObject *parent, const char *name) : QObject(parent, name),
-	menuid(0), gateways()
+void Sms::keyPressEvent(QKeyEvent *e)
+{
+	if (e->key() == Key_Escape)
+	{
+		e->accept();
+		close();
+	}
+	else
+		QWidget::keyPressEvent(e);
+}
+
+SmsConfigurationUiHandler::SmsConfigurationUiHandler()
+	: menuid(0), gateways()
 {
 	kdebugf();
+
+	createDefaultConfiguration();
+
 	UserBox::userboxmenu->addItemAtPos(2, "SendSms", tr("Send SMS"), this, SLOT(onSendSmsToUser()),
                 HotKey::shortCutFromFile("ShortCuts", "kadu_sendsms"));
 
-	menuid=kadu->mainMenu()->insertItem(icons_manager->loadIcon("SendSms"), tr("Send SMS"), this, SLOT(onSendSms()), 0, -1, 10);
-	icons_manager->registerMenuItem(kadu->mainMenu(), tr("Send SMS"), "SendSms");
+	QPopupMenu *MainMenu = kadu->mainMenu();
+	menuid = MainMenu->insertItem(icons_manager->loadIcon("SendSms"), tr("Send SMS"), this, SLOT(onSendSms()), 0, -1, 10);
+	icons_manager->registerMenuItem(MainMenu, tr("Send SMS"), "SendSms");
 
-	Action* send_sms_action = new Action(icons_manager->loadIcon("SendSms"),
-		tr("Send SMS"), "sendSmsAction", Action::TypeGlobal);
+	Action* send_sms_action = new Action("SendSms", tr("Send SMS"), "sendSmsAction", Action::TypeGlobal);
 	connect(send_sms_action, SIGNAL(activated(const UserGroup*, const QWidget*, bool)),
 		this, SLOT(sendSmsActionActivated(const UserGroup*)));
-	KaduActions.insert("sendSmsAction", send_sms_action);
 
 	kdebugf2();
 }
 
-SmsSlots::~SmsSlots()
+SmsConfigurationUiHandler::~SmsConfigurationUiHandler()
 {
 	kdebugf();
 	int sendsmstem = UserBox::userboxmenu->getItem(tr("Send SMS"));
 	UserBox::userboxmenu->removeItem(sendsmstem);
 	kadu->mainMenu()->removeItem(menuid);
-	KaduActions.remove("sendSmsAction");
+
+	Action *send_sms_action = KaduActions["sendSmsAction"];
+	delete send_sms_action;
 	kdebugf2();
 }
 
 
-void SmsSlots::onSmsBuildInCheckToggle(bool value)
+void SmsConfigurationUiHandler::onSmsBuildInCheckToggle(bool value)
 {
-	kdebugf();
-
-	QLineEdit *e_smsapp= ConfigDialog::getLineEdit("SMS", "Custom SMS application");
-	QCheckBox *b_smscustomconf= ConfigDialog::getCheckBox("SMS", "SMS custom string");
-	QLineEdit *e_smsconf= ConfigDialog::getLineEdit("SMS", 0, "smsstring");
-
-	((QHBox*)(e_smsapp->parent()))->setEnabled(!value);
-	b_smscustomconf->setEnabled(!value);
-	e_smsconf->setEnabled(b_smscustomconf->isChecked()&& !value);
-	kdebugf2();
-}
-
-void SmsSlots::onCreateTabSMS()
-{
-	kdebugf();
-
-	QCheckBox *b_smsbuildin= ConfigDialog::getCheckBox("SMS", "Use built-in SMS application");
-	QLineEdit *e_smsapp= ConfigDialog::getLineEdit("SMS", "Custom SMS application");
-	QCheckBox *b_smscustomconf= ConfigDialog::getCheckBox("SMS", "SMS custom string");
-	QLineEdit *e_smsconf= ConfigDialog::getLineEdit("SMS", 0, "smsstring");
-
-	if (b_smsbuildin->isChecked())
+	if (value)
 	{
-		((QHBox*)(e_smsapp->parent()))->setEnabled(false);
-		b_smscustomconf->setEnabled(false);
-		e_smsconf->setEnabled(false);
+		customApp->setEnabled(false);
+		useCustomString->setEnabled(false);
+		customString->setEnabled(false);
+	}
+	else
+	{
+		customApp->setEnabled(true);
+		useCustomString->setEnabled(true);
+		customString->setEnabled(useCustomString->isChecked());
 	}
-
-	if (!b_smscustomconf->isChecked())
-		e_smsconf->setEnabled(false);
-
-	connect(b_smscustomconf,SIGNAL(toggled(bool)),e_smsconf,SLOT(setEnabled(bool)));
-
-	QListBox* lb_gws=ConfigDialog::getListBox("SMS", "gateways");
-//	QMap<QString,isValidFunc*>::Iterator it;
-	QStringList priority=QStringList::split(";", config_file.readEntry("SMS", "Priority"));
-
-	CONST_FOREACH(gate, priority)
-		if (gateways.contains(*gate))
-			lb_gws->insertItem(*gate);
-
-	CONST_FOREACH(gate, gateways)
-		if (lb_gws->index(lb_gws->findItem(gate.key()))==-1)
-			lb_gws->insertItem(gate.key());
-
-	modules_manager->moduleIncUsageCount("sms");
-	kdebugf2();
 }
 
-void SmsSlots::onApplyTabSMS()
+void SmsConfigurationUiHandler::configurationUpdated()
 {
-	kdebugf();
-
-	QListBox* lb_gws=ConfigDialog::getListBox("SMS", "gateways");
 	QStringList priority;
-	QListBoxItem* lbi_item=lb_gws->firstItem();
+	QListBoxItem *item = gatewayListBox->firstItem();
 
-	while (lbi_item!=0)
+	while (item)
 	{
-		priority+=lbi_item->text();
-		lbi_item=lbi_item->next();
+		priority += item->text();
+		item = item->next();
 	}
 
+	// FIXME: : instead of ;
 	config_file.writeEntry("SMS", "Priority", priority.join(";"));
-	kdebugf2();
 }
 
-void SmsSlots::onCloseTabSMS()
+void SmsConfigurationUiHandler::newSms(QString nick)
 {
-	modules_manager->moduleDecUsageCount("sms");
+	(new Sms(nick, kadu, "sms"))->show();
 }
 
-void SmsSlots::newSms(QString nick)
-{
-	(new Sms(nick, NULL, "sms"))->show();
-}
-
-void SmsSlots::onUserClicked(int button, QListBoxItem* /*item*/, const QPoint& /*pos*/)
+void SmsConfigurationUiHandler::onUserClicked(int button, QListBoxItem* /*item*/, const QPoint& /*pos*/)
 {
 	if (button==4)
 		onSendSmsToUser();
 }
 
-void SmsSlots::onUserDblClicked(UserListElement user)
+void SmsConfigurationUiHandler::onUserDblClicked(UserListElement user)
 {
 	kdebugf();
-	if (!user.usesProtocol("Gadu") && !user.mobile().isEmpty())
+	if ((user.ID("Gadu") == kadu->myself().ID("Gadu") || !user.usesProtocol("Gadu")) && !user.mobile().isEmpty())
 		newSms(user.altNick());
 	kdebugf2();
 }
 
-void SmsSlots::onSendSmsToUser()
+void SmsConfigurationUiHandler::onSendSmsToUser()
 {
 	kdebugf();
 	UserListElements users;
@@ -599,12 +542,12 @@ void SmsSlots::onSendSmsToUser()
 	kdebugf2();
 }
 
-void SmsSlots::onSendSms()
+void SmsConfigurationUiHandler::onSendSms()
 {
 	newSms(QString::null);
 }
 
-void SmsSlots::registerGateway(QString name, isValidFunc* f)
+void SmsConfigurationUiHandler::registerGateway(QString name, isValidFunc* f)
 {
 	kdebugf();
 	QStringList priority=QStringList::split(";", config_file.readEntry("SMS", "Priority"));
@@ -617,14 +560,14 @@ void SmsSlots::registerGateway(QString name, isValidFunc* f)
 	kdebugf2();
 }
 
-void SmsSlots::unregisterGateway(QString name)
+void SmsConfigurationUiHandler::unregisterGateway(QString name)
 {
 	kdebugf();
 	gateways.remove(name);
 	kdebugf2();
 }
 
-SmsGateway* SmsSlots::getGateway(const QString& number)
+SmsGateway* SmsConfigurationUiHandler::getGateway(const QString& number)
 {
 	kdebugf();
 	QStringList priorities = QStringList::split(";", config_file.readEntry("SMS", "Priority"));
@@ -647,61 +590,111 @@ SmsGateway* SmsSlots::getGateway(const QString& number)
 	return NULL;
 }
 
-void SmsSlots::onUpButton()
+void SmsConfigurationUiHandler::onUpButton()
 {
-	kdebugf();
-	QListBox* list=ConfigDialog::getListBox("SMS", "gateways");
-	int index=list->currentItem();
-	if (index==0)
+	unsigned int index = gatewayListBox->currentItem();
+	if (index == 0)
 		return;
-	QString text=list->text(index);
-	list->removeItem(index);
-	list->insertItem(text, --index);
-	list->setSelected(list->findItem(text), true);
-	kdebugf2();
+
+	QString text = gatewayListBox->text(index);
+	gatewayListBox->removeItem(index);
+	gatewayListBox->insertItem(text, --index);
+	gatewayListBox->setSelected(gatewayListBox->findItem(text), true);
 }
 
-void SmsSlots::onDownButton()
+void SmsConfigurationUiHandler::onDownButton()
 {
-	kdebugf();
-	QListBox* list=ConfigDialog::getListBox("SMS", "gateways");
-	unsigned int index=list->currentItem();
-	if (index==list->count())
+	unsigned int index = gatewayListBox->currentItem();
+	if (index == gatewayListBox->count() - 1)
 		return;
-	QString text=list->text(index);
-	list->removeItem(index);
-	list->insertItem(text, ++index);
-	list->setSelected(list->findItem(text), true);
-	kdebugf2();
+
+	QString text = gatewayListBox->text(index);
+	gatewayListBox->removeItem(index);
+	gatewayListBox->insertItem(text, ++index);
+	gatewayListBox->setSelected(gatewayListBox->findItem(text), true);
 }
 
-void SmsSlots::onPopupMenuCreate()
+void SmsConfigurationUiHandler::onPopupMenuCreate()
 {
 	kdebugf();
-	UserListElements users;
+
 	UserBox *activeUserBox = kadu->userbox()->activeUserBox();
-	if (activeUserBox == NULL)//to si zdarza...
+	if (activeUserBox == NULL) //to sie zdarza...
 		return;
-	users = activeUserBox->selectedUsers();
-	UserListElement user = users[0];
 
-	if (user.mobile().isEmpty() || users.count() != 1)
-		UserBox::userboxmenu->setItemEnabled(UserBox::userboxmenu->getItem(tr("Send SMS")), false);
+	UserListElements users = activeUserBox->selectedUsers();
+	if ((users[0]).mobile().isEmpty() || users.count() != 1)
+		UserBox::userboxmenu->setItemVisible(UserBox::userboxmenu->getItem(tr("Send SMS")), false);
+
 	kdebugf2();
 }
 
-void SmsSlots::sendSmsActionActivated(const UserGroup* users)
+void SmsConfigurationUiHandler::sendSmsActionActivated(const UserGroup* users)
 {
 	kdebugf();
-	if (users != NULL && users->count() == 1 &&
-			(!(*users->begin()).mobile().isEmpty()))
+
+	if (users != NULL && users->count() == 1 && !(*users->begin()).mobile().isEmpty())
 		newSms((*users->begin()).altNick());
 	else
 		newSms(QString::null);
+
 	kdebugf2();
 }
 
-SmsSlots *smsslots;
+void SmsConfigurationUiHandler::mainConfigurationWindowCreated(MainConfigurationWindow *mainConfigurationWindow)
+{
+	useBuiltIn = dynamic_cast<QCheckBox *>(mainConfigurationWindow->widgetById("sms/useBuildInApp"));
+	customApp = dynamic_cast<QLineEdit *>(mainConfigurationWindow->widgetById("sms/customApp"));
+	useCustomString = dynamic_cast<QCheckBox *>(mainConfigurationWindow->widgetById("sms/useCustomString"));
+	customString = dynamic_cast<QLineEdit *>(mainConfigurationWindow->widgetById("sms/customString"));
+
+	ConfigGroupBox *gatewayGroupBox = mainConfigurationWindow->configGroupBox("SMS", "General", "Gateways");
+	QHBox *gatewayHBox = new QHBox(gatewayGroupBox->widget());
+	gatewayHBox->setSpacing(5);
+
+	gatewayListBox = new QListBox(gatewayHBox);
+
+	QWidget *buttons = new QWidget(gatewayHBox);
+	QVBoxLayout *buttonsLayout = new QVBoxLayout(buttons);
+	buttonsLayout->setSpacing(5);
+
+	QPushButton *up = new QPushButton(tr("Up"), buttons);
+	QPushButton *down = new QPushButton(tr("Down"), buttons);
+
+	buttonsLayout->addWidget(up);
+	buttonsLayout->addWidget(down);
+	buttonsLayout->addStretch(100);
+
+	connect(up, SIGNAL(clicked()), this, SLOT(onUpButton()));
+	connect(down, SIGNAL(clicked()), this, SLOT(onDownButton()));
+
+	gatewayGroupBox->addWidgets(new QLabel(tr("Gateways priorites"), gatewayGroupBox->widget()), gatewayHBox);
+	
+	connect(useBuiltIn, SIGNAL(toggled(bool)), this, SLOT(onSmsBuildInCheckToggle(bool)));
+	connect(useCustomString, SIGNAL(toggled(bool)), customString, SLOT(setEnabled(bool)));
+
+// TODO: fix it, should be ':' not ';'
+	QStringList priority = QStringList::split(";", config_file.readEntry("SMS", "Priority"));
+
+	CONST_FOREACH(gate, priority)
+		if (gateways.contains(*gate))
+			gatewayListBox->insertItem(*gate);
+
+	CONST_FOREACH(gate, gateways)
+		if (gatewayListBox->index(gatewayListBox->findItem(gate.key())) == -1)
+			gatewayListBox->insertItem(gate.key());
+}
+
+void SmsConfigurationUiHandler::createDefaultConfiguration()
+{
+	config_file.addVariable("SMS", "BuiltInApp", true);
+	config_file.addVariable("SMS", "SmsNick", "");
+	config_file.addVariable("SMS", "UseCustomString", false);
+
+	config_file.addVariable("ShortCuts", "kadu_sendsms", "Ctrl+S");
+}
+
+SmsConfigurationUiHandler *smsConfigurationUiHandler;
 
 /** @} */
 
