@@ -12,30 +12,10 @@
 
 #include "ssocket.h"
 
-
 class Pop3Proto: public QObject
 {
 	Q_OBJECT
-		
-	public:	
-		Pop3Proto(QString name, QString host, int port, QString user, QString password, SecureType type=WithoutEncryption);
-		~Pop3Proto();
-		void setName(QString name) { this->name=name; };
-		void setHost(QString host) { this->host=host; };
-		void setPort(int port) { this->port=port; };
-		void setUser(QString user) { this->user=user; };
-		void setPassword(QString password) { this->password=password; };
-		void setLastmails(int lastmails) { this->lastmails=lastmails; };
-		void setEncryption(SecureType type);
-		QString getName() { return name; };
-		QString getHost() { return host; };
-		int getPort() { return port; };
-		QString getUser() { return user; };
-		QString getPassword() { return password; };
-		int getLastmails() { return lastmails; };
-		void getStats();
-		SecureType getEncryption() { return encryption; };
-	private:
+
 		SSocket *mailserver;
 		enum State {
 			None,
@@ -46,9 +26,27 @@ class Pop3Proto: public QObject
 			Quit
 		} state;
 		void writesocket(QString* str);
-		QString name, host, user, password;
-		int port, lastmails;
-		SecureType encryption;
+		QString Name, Host, User, Password;
+		int Port, Lastmails;
+		SecureType Encryption;
+	public:	
+		Pop3Proto(QString name, QString host, int port, QString user, QString password, SecureType type=WithoutEncryption);
+		~Pop3Proto();
+		void setName(QString name) { Name=name; };
+		void setHost(QString host) { Host=host; };
+		void setPort(int port) { Port=port; };
+		void setUser(QString user) { User=user; };
+		void setPassword(QString password) { Password=password; };
+		void setLastmails(int lastmails) { Lastmails=lastmails; };
+		void setEncryption(SecureType type);
+		QString getName() { return Name; };
+		QString getHost() { return Host; };
+		int getPort() { return Port; };
+		QString getUser() { return User; };
+		QString getPassword() { return Password; };
+		int getLastmails() { return Lastmails; };
+		void getStats();
+		SecureType getEncryption() { return Encryption; };
 	public slots:
 		void connecterror(int error);
 		void connected();
